==> grafana-enterprise_12.2.0-17311094888_17311094888_windows_arm64.tar.gz: grafana-12.2.0-17311094888/public/app/extensions/query-library/QueryLibrary/QueryLibraryActions.test.tsx <==
import { screen } from '@testing-library/react';
import { FormProvider, useForm } from 'react-hook-form';
import { render } from 'test/test-utils';

import { mockQueryTemplateRow } from '../utils/mocks';

import { QueryLibraryActions, QueryLibraryActionsProps } from './QueryLibraryActions';
import { QueryDetails } from './QueryLibraryDetails';

const mockSetNewQuery = jest.fn();
jest.mock('app/features/explore/QueryLibrary/QueryLibraryContext', () => ({
  useQueryLibraryContext: () => ({
    triggerAnalyticsEvent: jest.fn(),
    setNewQuery: mockSetNewQuery,
  }),
}));

describe('QueryLibraryActions', () => {
  const mockOnSelectQuery = jest.fn();
  const defaultProps: QueryLibraryActionsProps = {
    onSelectQuery: mockOnSelectQuery,
    selectedQueryRow: mockQueryTemplateRow,
    isEditingQuery: false,
    onEditQuerySuccess: jest.fn(),
    setIsEditingQuery: jest.fn(),
    isSavingLoading: false,
  };

  const lockedQueryTemplateRow = {
    ...mockQueryTemplateRow,
    isLocked: true,
  };

  const lockedQueryProps: QueryLibraryActionsProps = {
    onSelectQuery: mockOnSelectQuery,
    selectedQueryRow: lockedQueryTemplateRow,
    isEditingQuery: false,
    onEditQuerySuccess: jest.fn(),
    setIsEditingQuery: jest.fn(),
    isSavingLoading: false,
  };

  beforeEach(() => {
    jest.clearAllMocks();
  });

  const QueryLibraryActionsWrapper = (props: QueryLibraryActionsProps) => {
    const methods = useForm<QueryDetails>();

    return (
      <FormProvider {...methods}>
        <QueryLibraryActions {...props} />
      </FormProvider>
    );
  };

  it('should render all action buttons not related to editing', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} />);
    expect(screen.getByRole('button', { name: 'Duplicate query' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Lock query' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Delete query' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Select query' })).toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Save' })).not.toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Cancel' })).not.toBeInTheDocument();
  });

  it('should not render update and select actions when query is new', () => {
    render(
      <QueryLibraryActionsWrapper {...defaultProps} selectedQueryRow={{ ...mockQueryTemplateRow, uid: undefined }} />
    );
    expect(screen.queryByRole('button', { name: 'Duplicate query' })).not.toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Lock query' })).not.toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Delete query' })).not.toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Select query' })).not.toBeInTheDocument();

    expect(screen.getByRole('button', { name: 'Save' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Cancel' })).toBeInTheDocument();
  });

  it('should render editing buttons when is editing query', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} isEditingQuery={true} />);
    expect(screen.getByRole('button', { name: 'Duplicate query' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Lock query' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Delete query' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Lock query' })).toBeDisabled();

    expect(screen.queryByRole('button', { name: 'Select query' })).not.toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Save' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Cancel' })).toBeInTheDocument();
  });

  it('should render unlock button when query is locked', () => {
    render(<QueryLibraryActionsWrapper {...lockedQueryProps} />);
    expect(screen.getByRole('button', { name: 'Unlock query' })).toBeInTheDocument();
  });

  it('should disable lock button when query is being edited', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} isEditingQuery={true} />);
    expect(screen.getByRole('button', { name: 'Lock query' })).toBeDisabled();
  });

  it('should call onSelectQuery when the select button is clicked', async () => {
    const { user } = render(<QueryLibraryActionsWrapper {...defaultProps} />);
    await user.click(screen.getByRole('button', { name: 'Select query' }));
    expect(mockOnSelectQuery).toHaveBeenCalledWith(mockQueryTemplateRow.query);
  });

  it('should set new query when duplicating query', async () => {
    const { user } = render(<QueryLibraryActionsWrapper {...defaultProps} />);
    await user.click(screen.getByRole('button', { name: 'Duplicate query' }));
    expect(mockSetNewQuery).toHaveBeenCalledWith({
      ...mockQueryTemplateRow,
      uid: undefined,
      title: `${mockQueryTemplateRow.title} Copy`,
    });
  });

  it('should only render save recent query button when using history', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} usingHistory={true} />);
    expect(screen.getByRole('button', { name: 'Save query' })).toBeInTheDocument();
  });

  it('should not render save recent query button when not using history', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} usingHistory={false} />);
    expect(screen.queryByRole('button', { name: 'Save query' })).not.toBeInTheDocument();
  });
});

==> grafana-enterprise_12.3.0-18578466485_18578466485_windows_arm64.tar.gz: grafana-12.3.0-18578466485/public/app/extensions/query-library/QueryLibrary/QueryLibraryActions.test.tsx <==
import { screen } from '@testing-library/react';
import { FormProvider, useForm } from 'react-hook-form';
import { render } from 'test/test-utils';

import { OrgRole } from '@grafana/data';
import { contextSrv } from 'app/core/services/context_srv';

import { mockSavedQuery } from '../utils/mocks';

import { QueryLibraryActions, QueryLibraryActionsProps } from './QueryLibraryActions';
import { QueryDetails } from './QueryLibraryDetails';

const mockSetNewQuery = jest.fn();
let mockContext = 'explore';
const mockCloseDrawer = jest.fn();
const mockOnSelectQuery = jest.fn();
jest.mock('app/features/explore/QueryLibrary/QueryLibraryContext', () => ({
  useQueryLibraryContext: () => ({
    triggerAnalyticsEvent: jest.fn(),
    setNewQuery: mockSetNewQuery,
    context: mockContext,
    closeDrawer: mockCloseDrawer,
    onSelectQuery: mockOnSelectQuery,
  }),
}));

describe('QueryLibraryActions', () => {
  const defaultProps: QueryLibraryActionsProps = {
    selectedQueryRow: mockSavedQuery,
    isEditingQuery: false,
    setIsEditingQuery: jest.fn(),
    isSavingLoading: false,
    onEditQuerySuccess: jest.fn(),
  };

  beforeEach(() => {
    jest.clearAllMocks();
    mockContext = 'explore';
  });

  const QueryLibraryActionsWrapper = (props: QueryLibraryActionsProps) => {
    const methods = useForm<QueryDetails>();

    return (
      <FormProvider {...methods}>
        <QueryLibraryActions {...props} />
      </FormProvider>
    );
  };

  it('should render all action buttons not related to editing', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} />);
    expect(screen.getByRole('button', { name: 'Select query' })).toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Save' })).not.toBeInTheDocument();
    expect(screen.queryByRole('button', { name: 'Cancel' })).not.toBeInTheDocument();
  });

  it('should not render update and select actions when query is new', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} selectedQueryRow={{ ...mockSavedQuery, uid: undefined }} />);
    expect(screen.queryByRole('button', { name: 'Select query' })).not.toBeInTheDocument();

    expect(screen.getByRole('button', { name: 'Save' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Cancel' })).toBeInTheDocument();
  });

  it('should render editing buttons when is editing query', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} isEditingQuery={true} />);
    expect(screen.queryByRole('button', { name: 'Select query' })).not.toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Save' })).toBeInTheDocument();
    expect(screen.getByRole('button', { name: 'Cancel' })).toBeInTheDocument();
  });

  it('should call onSelectQuery when the select button is clicked', async () => {
    const { user } = render(<QueryLibraryActionsWrapper {...defaultProps} />);
    await user.click(screen.getByRole('button', { name: 'Select query' }));
    expect(mockOnSelectQuery).toHaveBeenCalledWith(mockSavedQuery.query);
  });

  it('should only render save recent query button when using history', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} usingHistory={true} />);
    expect(screen.getByRole('button', { name: 'Save query' })).toBeInTheDocument();
  });

  it('should not render save recent query button when not using history', () => {
    render(<QueryLibraryActionsWrapper {...defaultProps} usingHistory={false} />);
    expect(screen.queryByRole('button', { name: 'Save query' })).not.toBeInTheDocument();
  });

  it('should render save and close button when context is unknown', () => {
    mockContext = 'unknown';
    render(<QueryLibraryActionsWrapper {...defaultProps} selectedQueryRow={{ ...mockSavedQuery, uid: undefined }} />);
    expect(screen.getByRole('button', { name: 'Save and close' })).toBeInTheDocument();
  });

  it('should call closeDrawer when context is unknown', async () => {
    mockContext = 'unknown';
    const { user } = render(
      <QueryLibraryActionsWrapper {...defaultProps} selectedQueryRow={{ ...mockSavedQuery, uid: undefined }} />
    );
    await user.click(screen.getByRole('button', { name: 'Cancel' }));
    expect(mockCloseDrawer).toHaveBeenCalled();
  });

  it('should disable save button when user is a viewer, even though they are the author', () => {
    contextSrv.user.uid = 'viewer:JohnDoe';
    contextSrv.user.orgRole = OrgRole.Viewer;
    render(<QueryLibraryActionsWrapper {...defaultProps} isEditingQuery={true} />);

    expect(screen.getByRole('button', { name: 'Save' })).toBeDisabled();
  });
});
